#[repr(u32)]pub enum LedConfigMode {
LED_CONFIG_MODE_ALL = 0,
LED_CONFIG_MODE_INDEX = 1,
LED_CONFIG_MODE_FOLLOW_FLIGHT_MODE = 2,
LED_CONFIG_MODE_CLEAR = 3,
}Available on crate feature
dialect-stemstudios only.Expand description
How to configure LEDs. We can: - Set all LEDs to the first color in our colors array. - Set up to 8 consecutive LEDs, starting from a given index, to colors provided in an array. - Set the LED colors to change according to the flight mode. - Turn all LEDs off (clear).
Variants
LED_CONFIG_MODE_ALL = 0
Set all LEDs in the target strip to the first color in our colors array.
LED_CONFIG_MODE_INDEX = 1
Set up to 8 consecutive LEDs, starting from the given index, to the colors provided in the colors array.
LED_CONFIG_MODE_FOLLOW_FLIGHT_MODE = 2
Set all LEDs in target strip to change color according to the flight mode.
LED_CONFIG_MODE_CLEAR = 3
Set all LEDs in the target strip to black (turn off).
Implementations
Sourceimpl LedConfigMode
impl LedConfigMode