#[repr(u32)]pub enum SafetySwitchState {
SAFETY_SWITCH_STATE_SAFE = 0,
SAFETY_SWITCH_STATE_DANGEROUS = 1,
}Available on crate feature
dialect-stemstudios only.Expand description
Possible safety switch states.
Variants
SAFETY_SWITCH_STATE_SAFE = 0
Safety switch is engaged and vehicle should be safe to approach.
SAFETY_SWITCH_STATE_DANGEROUS = 1
Safety switch is NOT engaged and motors, propellers and other actuators should be considered active.
Implementations