pub struct COMPONENT_INFORMATION_BASIC_DATA {
pub capabilities: MavProtocolCapability,
pub time_boot_ms: u32,
pub time_manufacture_s: u32,
pub vendor_name: CharArray<32>,
pub model_name: CharArray<32>,
pub software_version: CharArray<24>,
pub hardware_version: CharArray<24>,
pub serial_number: CharArray<32>,
}dialect-stemstudios only.Expand description
Basic component information data. Should be requested using MAV_CMD_REQUEST_MESSAGE on startup, or when required.
ID: 396
Fields
capabilities: MavProtocolCapabilityComponent capability flags
time_boot_ms: u32Timestamp (time since system boot).
time_manufacture_s: u32Date of manufacture as a UNIX Epoch time (since 1.1.1970) in seconds.
vendor_name: CharArray<32>Name of the component vendor. Needs to be zero terminated. The field is optional and can be empty/all zeros.
model_name: CharArray<32>Name of the component model. Needs to be zero terminated. The field is optional and can be empty/all zeros.
software_version: CharArray<24>Software version. The recommended format is SEMVER: ‘major.minor.patch’ (any format may be used). The field must be zero terminated if it has a value. The field is optional and can be empty/all zeros.
hardware_version: CharArray<24>Hardware version. The recommended format is SEMVER: ‘major.minor.patch’ (any format may be used). The field must be zero terminated if it has a value. The field is optional and can be empty/all zeros.
serial_number: CharArray<32>Hardware serial number. The field must be zero terminated if it has a value. The field is optional and can be empty/all zeros.
Implementations