pub struct MISSION_REQUEST_PARTIAL_LIST_DATA {
pub start_index: i16,
pub end_index: i16,
pub target_system: u8,
pub target_component: u8,
pub mission_type: MavMissionType,
}Available on crate feature
dialect-stemstudios only.Expand description
Request a partial list of mission items from the system/component. https://mavlink.io/en/services/mission.html. If start and end index are the same, just send one waypoint.
ID: 37
Fields
start_index: i16Start index
end_index: i16End index, -1 by default (-1: send list to end). Else a valid index of the list
target_system: u8System ID
target_component: u8Component ID
mission_type: MavMissionTypeMission type.
Implementations